@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.subnet
 
@@ -22,6 +22,13 @@ class AppsConfig(object):
             be specified by setting netmaskBits or netmaskIp4. The netmask can
             only be set using netmaskIp4 if the IP address is an IPv4
             address.
+        marketplace_apps_mode (MarketplaceAppsModeEnum): Specifies the various
+            modes for running marketplace apps.
+            'kDisabled' specifies that marketplace apps are disabled.
+            'kBareMetal' specifies that marketplace apps could only run in
+            containers on the node (no VM).
+            'kVmOnly' specifies that marketplace apps could only run in
+            containers on a VM hosted by the node.
         overcommit_memory_pct (int): The system memory to overcommit for
             apps.
         reserved_cpu_millicores (int): The CPU millicores to reserve for
@@ -36,6 +43,7 @@ class AppsConfig(object):
         "allow_unresticted_view_access":'allowUnrestictedViewAccess',
         "apps_mode":'appsMode',
         "apps_subnet":'appsSubnet',
+        "marketplace_apps_mode":'marketplaceAppsMode',
         "overcommit_memory_pct":'overcommitMemoryPct',
         "reserved_cpu_millicores":'reservedCpuMillicores',
         "reserved_memory_pct":'reservedMemoryPct'
@@ -46,6 +54,7 @@ class AppsConfig(object):
                  allow_unresticted_view_access=None,
                  apps_mode=None,
                  apps_subnet=None,
+                 marketplace_apps_mode=None,
                  overcommit_memory_pct=None,
                  reserved_cpu_millicores=None,
                  reserved_memory_pct=None):
@@ -56,6 +65,7 @@ class AppsConfig(object):
         self.allow_unresticted_view_access = allow_unresticted_view_access
         self.apps_mode = apps_mode
         self.apps_subnet = apps_subnet
+        self.marketplace_apps_mode = marketplace_apps_mode
         self.overcommit_memory_pct = overcommit_memory_pct
         self.reserved_cpu_millicores = reserved_cpu_millicores
         self.reserved_memory_pct = reserved_memory_pct
@@ -83,6 +93,7 @@ class AppsConfig(object):
         allow_unresticted_view_access = dictionary.get('allowUnrestictedViewAccess')
         apps_mode = dictionary.get('appsMode')
         apps_subnet = cohesity_management_sdk.models.subnet.Subnet.from_dictionary(dictionary.get('appsSubnet')) if dictionary.get('appsSubnet') else None
+        marketplace_apps_mode = dictionary.get('marketplaceAppsMode')
         overcommit_memory_pct = dictionary.get('overcommitMemoryPct')
         reserved_cpu_millicores = dictionary.get('reservedCpuMillicores')
         reserved_memory_pct = dictionary.get('reservedMemoryPct')
@@ -92,6 +103,7 @@ class AppsConfig(object):
                    allow_unresticted_view_access,
                    apps_mode,
                    apps_subnet,
+                   marketplace_apps_mode,
                    overcommit_memory_pct,
                    reserved_cpu_millicores,
                    reserved_memory_pct)
