@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 
 class AzureCredentials(object):
@@ -31,15 +31,21 @@ class AzureCredentials(object):
             subnet within the virtual network. 'kComputeOptions' indicates the
             number of CPU cores and memory size available for a type of a
             Virtual Machine.
+        domain_name (string): Specifies Azure stack hub domain name for where
+            the given subscription is present.
+        region (string): Specifies the region in which the Azure Stack will be
+            registered.
         subscription_id (string): Specifies Subscription id inside a
             customer's Azure account. It represents sub-section within the
             Azure account where a customer allows us to create VMs, storage
             account etc.
-        subscription_type (SubscriptionTypeAzureCredentialsEnum): Specifies
-            the subscription type of Azure such as 'kAzureCommercial' or
-            'kAzureGovCloud'. Specifies the subscription type of an Azure
-            source entity. 'kAzureCommercial' indicates a standard Azure
-            subscription. 'kAzureGovCloud' indicates a govt Azure
+        subscription_type (SubscriptionTypeAzureCredentialsEnum):
+            Specifies the subscription type of Azure such as 'kAzureCommercial',
+            'kAzureGovCloud' or 'kAzureStackCommercial'
+            Specifies the subscription type of an Azure source entity.
+            'kAzureCommercial' indicates a standard Azure subscription.
+            'kAzureGovCloud' indicates a govt Azure subscription.
+            'kAzureStackCommercial' indicates a stack commercial Azure
             subscription.
         tenant_id (string): Specifies Tenant Id of the active directory of
             Azure account.
@@ -51,6 +57,8 @@ class AzureCredentials(object):
         "application_id":'applicationId',
         "application_key":'applicationKey',
         "azure_type":'azureType',
+        "domain_name":'domainName',
+        "region":'region',
         "subscription_id":'subscriptionId',
         "subscription_type":'subscriptionType',
         "tenant_id":'tenantId'
@@ -60,6 +68,8 @@ class AzureCredentials(object):
                  application_id=None,
                  application_key=None,
                  azure_type=None,
+                 domain_name=None,
+                 region=None,
                  subscription_id=None,
                  subscription_type=None,
                  tenant_id=None):
@@ -69,6 +79,8 @@ class AzureCredentials(object):
         self.application_id = application_id
         self.application_key = application_key
         self.azure_type = azure_type
+        self.domain_name = domain_name
+        self.region = region
         self.subscription_id = subscription_id
         self.subscription_type = subscription_type
         self.tenant_id = tenant_id
@@ -95,6 +107,8 @@ class AzureCredentials(object):
         application_id = dictionary.get('applicationId')
         application_key = dictionary.get('applicationKey')
         azure_type = dictionary.get('azureType')
+        domain_name = dictionary.get('domainName')
+        region = dictionary.get('region')
         subscription_id = dictionary.get('subscriptionId')
         subscription_type = dictionary.get('subscriptionType')
         tenant_id = dictionary.get('tenantId')
@@ -103,6 +117,8 @@ class AzureCredentials(object):
         return cls(application_id,
                    application_key,
                    azure_type,
+                   domain_name,
+                   region,
                    subscription_id,
                    subscription_type,
                    tenant_id)
