@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.alerting_policy_proto
 import cohesity_management_sdk.models.backup_source_params
@@ -14,8 +14,11 @@ import cohesity_management_sdk.models.universal_id_proto
 import cohesity_management_sdk.models.backup_job_pre_or_post_script
 import cohesity_management_sdk.models.backup_job_proto_backup_source
 import cohesity_management_sdk.models.time
+import cohesity_management_sdk.models.source_filters
 import cohesity_management_sdk.models.stubbing_policy_proto
+import cohesity_management_sdk.models.standby_resource
 import cohesity_management_sdk.models.user_information
+import cohesity_management_sdk.models.backup_job_proto_remote_view_params
 import cohesity_management_sdk.models.physical_file_backup_params_global_include_exclude
 
 class BackupJobProto(object):
@@ -30,6 +33,12 @@ class BackupJobProto(object):
             (assuming that it was started earlier when it was not in an
             exclusion window).
         alerting_policy (AlertingPolicyProto): TODO: type description here.
+        all_archival_snapshots_expired (bool): If job deletion status is
+            kDeleteJobAndBackups and this field is set to true, then it 
+            implies that expiration requests for all archival snapshots
+            of this job (if any) have been acknowledged by Icebox.
+            NOTE: This field may remain false for some period of time even if
+            is_deleted field is set to true for the job.
         backup_qos_principal (int): The backup QoS principal to use for the
             backup job.
         backup_source_params (list of BackupSourceParams): This contains
@@ -46,6 +55,9 @@ class BackupJobProto(object):
             by the user, a remote view is created with the same name as source
             view name. 2) Remote view name is provided by the user, a remote
             view is created with the given name.
+            NOTE: From 6.6 onwards, remote view is always created for view backups if
+            policy has replication. Hence, this bool is only used for Remote Adapter
+            jobs (kPuppeteer).
         dedup_disabled_source_id_vec (list of long|int): List of source ids
             for which source side dedup is disabled from the backup job.
         deletion_status (int): Determines if the job (and associated backups)
@@ -86,15 +98,30 @@ class BackupJobProto(object):
         is_active (bool): Whether the backup job is active or not. Details
             about what an active job is can be found here:
             https://goo.gl/1mLvS3.
+        is_cdp_sync_replication_enabled (bool): If set to true and backup job policy
+            has CDP parameters as well as snapshot replication target policy is
+            specified then data is synchronously replicated to the replication
+            target through Atom service.
+        is_cloud_archive_direct (bool): Denotes whether the backup job is
+            CloudArchiveDirect (excluding NAS direct archive in native format).
+            NAS direct archive jobs in native format can be
+            identified by checking for the 'is_direct_archive_enabled' field.
         is_continuous_snapshotting_enabled (bool): Indicates if Magneto should
             continue taking source snapshots even if there is a pending run.
         is_deleted (bool): Tracks whether the backup job has actually been
             deleted.
+            NOTE: If job deletion status is kDeleteJobAndBackups and this
+            field is true, then it only implies that all local snapshots
+            have been deleted.Status of whether all archival snapshots have
+            been expired can be inferred through
+            'all_archival_snapshots_expired' field.
         is_direct_archive_enabled (bool): This field is set to true if this is
             a direct archive backup job.
         is_direct_archive_native_format_enabled (bool): This field is set to
             true if native format should be used for archiving. Applicable for
             only direct archive jobs.
+        is_internal (bool): Whether the backup job is an internal job. These
+            jobs are hidden from the user, and are created internally.
         is_paused (bool): Whether the backup job is paused. New backup runs
             are not scheduled for the paused backup job. Active run of a
             backup job (if any) is not impacted.
@@ -150,8 +177,11 @@ class BackupJobProto(object):
             environment. If not specified, then snapshots will not be be
             deleted from the primary environment. NOTE: This is only
             applicable for certain environments like kPure.
-        parent_source (EntityProto): Specifies the attributes and the latest
-            statistics about an entity.
+        object_backup_spec_uid (UniversalIdProto): The universal Id of the
+            ObjectBackupSpecification which is used by this backup job.This is
+            relavent only for internal jobs.
+        parent_source (EntityProto): The registered source managing all the
+            sources being backed up. This field is optional.
         perform_source_side_dedup (bool): Whether or not to perform source
             side dedup.
         policy_applied_time_msecs (long|int): Epoch time in milliseconds when
@@ -199,6 +229,11 @@ class BackupJobProto(object):
             same (which is equal to the job id from the original cluster A).
         remote_view_name (string): A human readable name of the remote view. A
             remote view is created with name overwriting the latest snapshot.
+            NOTE: From 6.6 onwards, we support protecting multiple views within a
+            protection group, 'remoteViewParams' is the new field which captures
+            this information for view backups, 'remote_view_name' here is now only
+            used for Remote Adapter jobs (kPuppeteer).
+        remote_view_params (BackupJobProto_RemoteViewParams): TODO:
         required_feature_vec (list of string): The features that are strictly
             required to be supported by the cluster of the backup job. This is
             currently used in the following cases: 1. Tx cluster looks at the
@@ -207,6 +242,8 @@ class BackupJobProto(object):
             performing remote restore of a backup job from an archival, this
             job will be retrieved only if the cluster supports all the
             features listed here.
+        skip_tenant_validations (bool): If set to true, skips tenant related
+            validations. Default is false.
         sla_time_mins (long|int): If specified, this variable determines the
             amount of time (after backup has started) in which backup is
             expected to finish for this job. An SLA violation is counted
@@ -218,6 +255,13 @@ class BackupJobProto(object):
             should be backed up. A source in this list could be a descendant
             of another source in the list (this will be used when specifying
             override backup schedules).
+        standby_resource_vec (list of StandbyResource): User provided resource(s)
+            for creating a standby VM for each entity
+            present in this backup job. For example in case of VMware, the user will
+            provide the vCenter, datastore and resource pool on which the standby VM
+            should be created.
+            TODO(hmehra) Can the user edit this after the job is created or the
+            resources have been specified?
         start_time (Time): A message to encapusulate time of a day. Users of
             this proto will have to store the timezone information separately.
             For example, when this proto is part of a backup job, timezone of
@@ -253,6 +297,7 @@ class BackupJobProto(object):
     _names = {
         "abort_in_exclusion_window":'abortInExclusionWindow',
         "alerting_policy":'alertingPolicy',
+        "all_archival_snapshots_expired":'allArchivalSnapshotsExpired',
         "backup_qos_principal":'backupQosPrincipal',
         "backup_source_params":'backupSourceParams',
         "continue_on_quiesce_failure":'continueOnQuiesceFailure',
@@ -272,10 +317,13 @@ class BackupJobProto(object):
         "global_include_exclude":'globalIncludeExclude',
         "indexing_policy":'indexingPolicy',
         "is_active":'isActive',
+        "is_cdp_sync_replication_enabled":'isCdpSyncReplicationEnabled',
+        "is_cloud_archive_direct":'isCloudArchiveDirect',
         "is_continuous_snapshotting_enabled":'isContinuousSnapshottingEnabled',
         "is_deleted":'isDeleted',
         "is_direct_archive_enabled":'isDirectArchiveEnabled',
         "is_direct_archive_native_format_enabled":'isDirectArchiveNativeFormatEnabled',
+        "is_internal":'isInternal',
         "is_paused":'isPaused',
         "is_rpo_job":'isRpoJob',
         "job_creation_time_usecs":'jobCreationTimeUsecs',
@@ -293,6 +341,7 @@ class BackupJobProto(object):
         "max_allowed_source_snapshots":'maxAllowedSourceSnapshots',
         "name":'name',
         "num_snapshots_to_keep_on_primary":'numSnapshotsToKeepOnPrimary',
+        "object_backup_spec_uid":'object_backup_spec_uid',
         "parent_source":'parentSource',
         "perform_source_side_dedup":'performSourceSideDedup',
         "policy_applied_time_msecs":'policyAppliedTimeMsecs',
@@ -305,10 +354,13 @@ class BackupJobProto(object):
         "quiesce":'quiesce',
         "remote_job_uids":'remoteJobUids',
         "remote_view_name":'remoteViewName',
+        "remote_view_params":'remoteViewParams',
         "required_feature_vec":'requiredFeatureVec',
+        "skip_tenant_validations":'skipTenantValidations',
         "sla_time_mins":'slaTimeMins',
         "source_filters":'sourceFilters',
         "sources":'sources',
+        "standby_resource_vec":'standby_resource_vec',
         "start_time":'startTime',
         "stubbing_policy":'stubbingPolicy',
         "tag_vec":'tagVec',
@@ -322,6 +374,7 @@ class BackupJobProto(object):
     def __init__(self,
                  abort_in_exclusion_window=None,
                  alerting_policy=None,
+                 all_archival_snapshots_expired=None,
                  backup_qos_principal=None,
                  backup_source_params=None,
                  continue_on_quiesce_failure=None,
@@ -341,10 +394,13 @@ class BackupJobProto(object):
                  global_include_exclude=None,
                  indexing_policy=None,
                  is_active=None,
+                 is_cdp_sync_replication_enabled=None,
+                 is_cloud_archive_direct=None,
                  is_continuous_snapshotting_enabled=None,
                  is_deleted=None,
                  is_direct_archive_enabled=None,
                  is_direct_archive_native_format_enabled=None,
+                 is_internal=None,
                  is_paused=None,
                  is_rpo_job=None,
                  job_creation_time_usecs=None,
@@ -362,6 +418,7 @@ class BackupJobProto(object):
                  max_allowed_source_snapshots=None,
                  name=None,
                  num_snapshots_to_keep_on_primary=None,
+                 object_backup_spec_uid=None,
                  parent_source=None,
                  perform_source_side_dedup=None,
                  policy_applied_time_msecs=None,
@@ -374,10 +431,13 @@ class BackupJobProto(object):
                  quiesce=None,
                  remote_job_uids=None,
                  remote_view_name=None,
+                 remote_view_params=None,
                  required_feature_vec=None,
+                 skip_tenant_validations=None,
                  sla_time_mins=None,
                  source_filters=None,
                  sources=None,
+                 standby_resource_vec=None,
                  start_time=None,
                  stubbing_policy=None,
                  tag_vec=None,
@@ -391,6 +451,7 @@ class BackupJobProto(object):
         # Initialize members of the class
         self.abort_in_exclusion_window = abort_in_exclusion_window
         self.alerting_policy = alerting_policy
+        self.all_archival_snapshots_expired = all_archival_snapshots_expired
         self.backup_qos_principal = backup_qos_principal
         self.backup_source_params = backup_source_params
         self.continue_on_quiesce_failure = continue_on_quiesce_failure
@@ -410,10 +471,13 @@ class BackupJobProto(object):
         self.global_include_exclude = global_include_exclude
         self.indexing_policy = indexing_policy
         self.is_active = is_active
+        self.is_cdp_sync_replication_enabled = is_cdp_sync_replication_enabled
+        self.is_cloud_archive_direct = is_cloud_archive_direct
         self.is_continuous_snapshotting_enabled = is_continuous_snapshotting_enabled
         self.is_deleted = is_deleted
         self.is_direct_archive_enabled = is_direct_archive_enabled
         self.is_direct_archive_native_format_enabled = is_direct_archive_native_format_enabled
+        self.is_internal = is_internal
         self.is_paused = is_paused
         self.is_rpo_job = is_rpo_job
         self.job_creation_time_usecs = job_creation_time_usecs
@@ -431,6 +495,7 @@ class BackupJobProto(object):
         self.max_allowed_source_snapshots = max_allowed_source_snapshots
         self.name = name
         self.num_snapshots_to_keep_on_primary = num_snapshots_to_keep_on_primary
+        self.object_backup_spec_uid = object_backup_spec_uid
         self.parent_source = parent_source
         self.perform_source_side_dedup = perform_source_side_dedup
         self.policy_applied_time_msecs = policy_applied_time_msecs
@@ -443,10 +508,13 @@ class BackupJobProto(object):
         self.quiesce = quiesce
         self.remote_job_uids = remote_job_uids
         self.remote_view_name = remote_view_name
+        self.remote_view_params = remote_view_params
         self.required_feature_vec = required_feature_vec
+        self.skip_tenant_validations = skip_tenant_validations
         self.sla_time_mins = sla_time_mins
         self.source_filters = source_filters
         self.sources = sources
+        self.standby_resource_vec = standby_resource_vec
         self.start_time = start_time
         self.stubbing_policy = stubbing_policy
         self.tag_vec = tag_vec
@@ -477,6 +545,7 @@ class BackupJobProto(object):
         # Extract variables from the dictionary
         abort_in_exclusion_window = dictionary.get('abortInExclusionWindow')
         alerting_policy = cohesity_management_sdk.models.alerting_policy_proto.AlertingPolicyProto.from_dictionary(dictionary.get('alertingPolicy')) if dictionary.get('alertingPolicy') else None
+        all_archival_snapshots_expired = dictionary.get('allArchivalSnapshotsExpired')
         backup_qos_principal = dictionary.get('backupQosPrincipal')
         backup_source_params = None
         if dictionary.get('backupSourceParams') != None:
@@ -512,10 +581,13 @@ class BackupJobProto(object):
         global_include_exclude = cohesity_management_sdk.models.physical_file_backup_params_global_include_exclude.PhysicalFileBackupParams_GlobalIncludeExclude.from_dictionary(dictionary.get('globalIncludeExclude')) if dictionary.get('globalIncludeExclude') else None
         indexing_policy = cohesity_management_sdk.models.indexing_policy_proto.IndexingPolicyProto.from_dictionary(dictionary.get('indexingPolicy')) if dictionary.get('indexingPolicy') else None
         is_active = dictionary.get('isActive')
+        is_cdp_sync_replication_enabled = dictionary.get('isCdpSyncReplicationEnabled')
+        is_cloud_archive_direct = dictionary.get('isCloudArchiveDirect')
         is_continuous_snapshotting_enabled = dictionary.get('isContinuousSnapshottingEnabled')
         is_deleted = dictionary.get('isDeleted')
         is_direct_archive_enabled = dictionary.get('isDirectArchiveEnabled')
         is_direct_archive_native_format_enabled = dictionary.get('isDirectArchiveNativeFormatEnabled')
+        is_internal = dictionary.get('isInternal')
         is_paused = dictionary.get('isPaused')
         is_rpo_job = dictionary.get('isRpoJob')
         job_creation_time_usecs = dictionary.get('jobCreationTimeUsecs')
@@ -533,6 +605,7 @@ class BackupJobProto(object):
         max_allowed_source_snapshots = dictionary.get('maxAllowedSourceSnapshots')
         name = dictionary.get('name')
         num_snapshots_to_keep_on_primary = dictionary.get('numSnapshotsToKeepOnPrimary')
+        object_backup_spec_uid = cohesity_management_sdk.models.universal_id_proto.UniversalIdProto.from_dictionary(dictionary.get('objectBackupSpecUid')) if dictionary.get('objectBackupSpecUid') else None
         parent_source = cohesity_management_sdk.models.entity_proto.EntityProto.from_dictionary(dictionary.get('parentSource')) if dictionary.get('parentSource') else None
         perform_source_side_dedup = dictionary.get('performSourceSideDedup')
         policy_applied_time_msecs = dictionary.get('policyAppliedTimeMsecs')
@@ -549,7 +622,9 @@ class BackupJobProto(object):
             for structure in dictionary.get('remoteJobUids'):
                 remote_job_uids.append(cohesity_management_sdk.models.universal_id_proto.UniversalIdProto.from_dictionary(structure))
         remote_view_name = dictionary.get('remoteViewName')
+        remote_view_params = cohesity_management_sdk.models.backup_job_proto_remote_view_params.BackupJobProto_RemoteViewParams.from_dictionary(dictionary.get('remoteViewParams')) if dictionary.get('remoteViewParams') else None
         required_feature_vec = dictionary.get('requiredFeatureVec')
+        skip_tenant_validations = dictionary.get('skipTenantValidations')
         sla_time_mins = dictionary.get('slaTimeMins')
         source_filters = cohesity_management_sdk.models.source_filters.SourceFilters.from_dictionary(dictionary.get('sourceFilters')) if dictionary.get('sourceFilters') else None
         sources = None
@@ -557,6 +632,11 @@ class BackupJobProto(object):
             sources = list()
             for structure in dictionary.get('sources'):
                 sources.append(cohesity_management_sdk.models.backup_job_proto_backup_source.BackupJobProtoBackupSource.from_dictionary(structure))
+        standby_resource_vec = None
+        if dictionary.get('standby_resource_vec') != None:
+            standby_resource_vec = list()
+            for structure in dictionary.get('standby_resource_vec'):
+                standby_resource_vec.append(cohesity_management_sdk.models.standby_resource.StandbyResource.from_dictionary(structure))
         start_time = cohesity_management_sdk.models.time.Time.from_dictionary(dictionary.get('startTime')) if dictionary.get('startTime') else None
         stubbing_policy = cohesity_management_sdk.models.stubbing_policy_proto.StubbingPolicyProto.from_dictionary(dictionary.get('stubbingPolicy')) if dictionary.get('stubbingPolicy') else None
         tag_vec = dictionary.get('tagVec')
@@ -569,6 +649,7 @@ class BackupJobProto(object):
         # Return an object of this model
         return cls(abort_in_exclusion_window,
                    alerting_policy,
+                   all_archival_snapshots_expired,
                    backup_qos_principal,
                    backup_source_params,
                    continue_on_quiesce_failure,
@@ -588,10 +669,13 @@ class BackupJobProto(object):
                    global_include_exclude,
                    indexing_policy,
                    is_active,
+                   is_cdp_sync_replication_enabled,
+                   is_cloud_archive_direct,
                    is_continuous_snapshotting_enabled,
                    is_deleted,
                    is_direct_archive_enabled,
                    is_direct_archive_native_format_enabled,
+                   is_internal,
                    is_paused,
                    is_rpo_job,
                    job_creation_time_usecs,
@@ -609,6 +693,7 @@ class BackupJobProto(object):
                    max_allowed_source_snapshots,
                    name,
                    num_snapshots_to_keep_on_primary,
+                   object_backup_spec_uid,
                    parent_source,
                    perform_source_side_dedup,
                    policy_applied_time_msecs,
@@ -621,7 +706,9 @@ class BackupJobProto(object):
                    quiesce,
                    remote_job_uids,
                    remote_view_name,
+                   remote_view_params,
                    required_feature_vec,
+                   skip_tenant_validations,
                    sla_time_mins,
                    source_filters,
                    sources,
