@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 
 class Subnet(object):
@@ -35,6 +35,13 @@ class Subnet(object):
             indicates Protocol access level 'Disabled' 'kReadOnly' indicates
             Protocol access level 'ReadOnly' 'kReadWrite' indicates Protocol
             access level 'ReadWrite'
+        s3_access (S3AccessEnum): Specifies whether clients from this subnet
+            can access using S3 protocol.
+            Protocol access level.
+            'kDisabled' indicates Protocol access level 'Disabled'
+            'kReadOnly' indicates Protocol access level 'ReadOnly'
+            'kReadWrite' indicates Protocol access level 'ReadWrite'
+        tenant_id (string): Specifies the unique id of the tenant.
 
     """
 
@@ -49,7 +56,9 @@ class Subnet(object):
         "nfs_access":'nfsAccess',
         "nfs_all_squash":'nfsAllSquash',
         "nfs_root_squash":'nfsRootSquash',
-        "smb_access":'smbAccess'
+        "s3_access":'s3Access',
+        "smb_access":'smbAccess',
+        "tenant_id":'tenantId'
     }
 
     def __init__(self,
@@ -62,7 +71,9 @@ class Subnet(object):
                  nfs_access=None,
                  nfs_all_squash=None,
                  nfs_root_squash=None,
-                 smb_access=None):
+                 s3_access=None,
+                 smb_access=None,
+                 tenant_id=None):
         """Constructor for the Subnet class"""
 
         # Initialize members of the class
@@ -75,7 +86,9 @@ class Subnet(object):
         self.nfs_access = nfs_access
         self.nfs_all_squash = nfs_all_squash
         self.nfs_root_squash = nfs_root_squash
+        self.s3_access = s3_access
         self.smb_access = smb_access
+        self.tenant_id = tenant_id
 
 
     @classmethod
@@ -105,7 +118,9 @@ class Subnet(object):
         nfs_access = dictionary.get('nfsAccess')
         nfs_all_squash = dictionary.get('nfsAllSquash')
         nfs_root_squash = dictionary.get('nfsRootSquash')
+        s3_access = dictionary.get('s3Access')
         smb_access = dictionary.get('smbAccess')
+        tenant_id = dictionary.get('tenantId')
 
         # Return an object of this model
         return cls(component,
@@ -117,6 +132,8 @@ class Subnet(object):
                    nfs_access,
                    nfs_all_squash,
                    nfs_root_squash,
-                   smb_access)
+                   s3_access,
+                   smb_access,
+                   tenant_id)
 
 
