@@ -3,23 +3,28 @@
 # Python utility to export the cluster config.
 # Usage: python export_cluster_config.py
 
-import argparse
-import datetime
-import json
-import logging
-import pickle
-import os
-import requests
-import sys
-import library
-
-# Custom module import
-from cohesity_management_sdk.cohesity_client import CohesityClient
-from cohesity_management_sdk.exceptions.api_exception import APIException
-from cohesity_management_sdk.models.environment_register_protection_source_parameters_enum \
-    import EnvironmentRegisterProtectionSourceParametersEnum as env_enum
-from library import RestClient
+try:
+    import argparse
+    import datetime
+    import json
+    import logging
+    import pickle
+    import os
+    import requests
+    import sys
+    import library
 
+    # Custom module import
+    from cohesity_management_sdk.cohesity_client import CohesityClient
+    from cohesity_management_sdk.exceptions.api_exception import APIException
+    from cohesity_management_sdk.models.environment_register_protection_source_parameters_enum \
+        import EnvironmentRegisterProtectionSourceParametersEnum as env_enum
+    from library import RestClient
+except ImportError as err:
+    print("Please ensure Cohesity Python SDK and dependency packages are installed to continue.")
+    print("To install Python SDK, run 'pip install cohesity-management-sdk'")
+    print("To install dependencies, run 'sh setup.py'")
+    exit()
 
 # Disable python warnings.
 requests.packages.urllib3.disable_warnings()
@@ -30,6 +35,8 @@ if float(sys.version[:3]) >= 3:
 else:
     import ConfigParser as configparser
 
+from configparser import NoSectionError, NoOptionError
+
 logger = logging.getLogger('export_app')
 
 # Fetch command line arguments.
@@ -70,21 +77,38 @@ logger.setLevel(logging.INFO)
 logger.info("Exporting resources from cluster '%s'" % (
     configparser.get('export_cluster_config', 'cluster_ip')))
 
+try:
+    # Skip paused jobs and failover ready jobs by setting this flag to true
+    # in config file.
+    skip_jobs = configparser.getboolean('export_cluster_config', 'skip_jobs')
+    export_access_mgmnt = configparser.getboolean(
+            'export_cluster_config', 'export_access_management')
+except (NoSectionError, NoOptionError) as err:
+    print("Error while fetching 'config.ini' content, error msg %s" % err)
+
 
 cluster_dict = {
     "cluster_config": library.get_cluster_config(cohesity_client),
     "views": library.get_views(cohesity_client),
     "storage_domains": library.get_storage_domains(cohesity_client),
     "policies": library.get_protection_policies(cohesity_client),
-    "protection_jobs": library.get_protection_jobs(cohesity_client),
+    "protection_jobs": library.get_protection_jobs(cohesity_client, skip_jobs),
     "protection_sources": library.get_protection_sources(cohesity_client),
     "external_targets": library.get_external_targets(cohesity_client),
     "sources": library.get_protection_sources(cohesity_client),
     "remote_clusters": library.get_remote_clusters(cohesity_client),
     "sql_entity_mapping": library.get_sql_entity_mapping(cohesity_client,
-                                                         env_enum.KSQL)
+                                                         env_enum.KSQL),
+    "ad_entity_mapping": library.get_ad_entity_mapping(cohesity_client,
+                                                         env_enum.KAD)
 }
 
+# Export Active directory entries and AD users and groups along with roles.
+if export_access_mgmnt:
+    cluster_dict["ad"] = library.get_ad_entries(cohesity_client)
+    cluster_dict["ad_objects"] = library.get_ad_objects(cohesity_client)
+    cluster_dict["roles"] = cohesity_client.roles.get_roles()
+
 exported_res = library.debug()
 source_dct = {}
 KCASSANDRA = "kCassandra"
@@ -92,13 +116,14 @@ KCASSANDRA = "kCassandra"
 # List of support environments.
 env_list = [env_enum.KGENERICNAS, env_enum.KISILON, env_enum.KPHYSICAL,
             env_enum.KPHYSICALFILES, env_enum.KVIEW, env_enum.K_VMWARE,
-            env_enum.KSQL, KCASSANDRA]
+            env_enum.KSQL, KCASSANDRA, env_enum.KAD]
 
 
 for source in cluster_dict["sources"]:
     id = source.protection_source.id
     env = source.protection_source.environment
     rest_obj = RestClient(cluster_vip, username, password, domain)
+
     if env == "kCassandra":
         api = "public/protectionSources?id={}&environment={}".format(id, env)
         _, resp = rest_obj.get(api=api)
